@@ -195,9 +195,10 @@ class ANA():
             file_list.append(self.files[i])
         # file_list = np.array([f.split('\\') for f in file_list])
         spot_num = [int(f[:-3].split('_')[2]) + 1 for f in file_list]
+        file_names = [f.name for f in sorted(Path(self.directory).glob('*.h5'))]
 
-        self.data = pd.DataFrame(data={'Experiment': file_list[:, 0],
-                                       'Files': file_list[:, 1],
+        self.data = pd.DataFrame(data={'Experiment': str(self.directory),
+                                       'Files': file_names,
                                        'Spot': spot_num,
                                        'Data': data_list})
 
@@ -340,6 +341,7 @@ class ANA():
     def _filelist(self):
         self.files = [str(file) for file in sorted(self.directory.glob('scalar*.h5'))]
         self.files.sort(key=self._natural_keys)
+        # self.files.sort(key=self._natural_keys)
     
     # sorts list numerically
     def _atoi(self, text):
